# Define if you want to build the sane backend (default)
%define sane_backend 1

##### GENERAL STUFF #####

Summary:	HP OfficeJet low level driver infrastructure
Name:		hpoj
Version:	0.90
Release:	1
License:	GPL
Group:		System/Servers


##### SOURCE FILES #####

Source: http://hpoj.sourceforge.net/download/%{name}-%{version}.tar.bz2
# Icon for the Mandrake menu
Source3: hpoj.png.bz2
# Wrapper script to start "xojpanel" with device auto-detection
Source6: allxojpanels.bz2
Patch0: hpoj-ppc.patch.bz2
Patch1: hpoj-0.90-rh8-snmp.patch

# lib64 fixes
Patch4: hpoj-lib64.patch.bz2

Patch5: hpoj-0.90-split-the-glob-with-spaces-to-please-perl-base.patch.bz2

##### ADDITIONAL DEFINITIONS #####

Url: http://hpoj.sourceforge.net
Requires: net-snmp
%if %{sane_backend}
BuildRequires: sane-backends-devel
%endif
BuildRequires: net-snmp-devel, qt3-devel, openssl-devel
BuildRoot: %{_tmppath}/%{name}-buildroot
Conflicts: cups <= 1.1.14

%description

This is an HP-sponsored project to add Linux support for most
Hewlett-Packard OfficeJet, PSC, and LaserJet all-in-one peripherals
(also known as Multi-Function Peripherals or MFPs), which can print,
scan, copy, and (on some models) fax.

It is work in progress, but printing and scanning are supported on
most models, when either connected to the parallel port or USB on a
Linux (Intel or Alpha) workstation, or to a LAN with selected HP
JetDirect print servers.


##### SUB-PACKAGES #####

%if %{sane_backend}
%package -n libsane-hpoj
Summary: SANE driver for scanners in HP's multi-function devices (from HPOJ)
Group: System/Servers
Requires: sane-backends
%endif

%if %{sane_backend}
%description -n libsane-hpoj
SANE driver for scanners in HP's multi-function devices (from HPOJ)
%endif

%package -n hpoj-devel
Summary: Headers required to compile against the "hpoj" library
Group: Development/C
Requires: hpoj >= %{version}-%{release}
Provides: hpoj-devel = %{version}-%{release}

%description -n hpoj-devel
This package contains all the files which are required to compiles programs
using the "hpoj" libraries.

%package -n xojpanel
Summary: Graphical tool displaying the contents of the LCD of HP printers
Group: System/Servers
Requires: hpoj
Conflicts: hpoj < 0.90-1

%description -n xojpanel
Graphical tool displaying the contents of the LCD of HP multi-function
devices and laser printers. Very useful to monitor the state (paper, ink,
running job) of a printer directly on one's workstation's screen.

##### PREP #####

%prep
rm -rf $RPM_BUILD_DIR/%{name}-%{version}
%setup -q -n %{name}-%{version}

%ifarch ppc
%patch0 -p1
%endif
#%patch4 -p1 -b .lib64
%patch5 -p1
%patch1 -p1

# needed by Patch4
#autoconf

# Load menu icon
bzcat %{SOURCE3} > hpoj.png
# Load "xojpanel" wrapper script
bzcat %{SOURCE6} > allxojpanels

##### BUILD #####

%build
#%serverbuild

# Fix hard-coded paths, also take into account paths mentioned in the docs
for i in `find . -type f -print`; do
    perl -p -i -e "s!doc/hpoj!doc/%{name}-%{version}!" $i
done
# Only needed for CVS snapshots
#autoconf

%if !%{sane_backend}
WITHOUT_SANE="--without-sane"
%endif
%configure --with-qt=/usr/lib/qt3 --enable-mt $WITHOUT_SANE
#--sysconfdir=/etc 

# Do not use the macro, it has parallelizing problems
make	etcdir=%{_sysconfdir} docdir=%{_docdir}/%{name}-%{version}

##### INSTALL #####

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_initrddir}

%makeinstall etcdir=%{buildroot}%{_sysconfdir}

# install menu icon
mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/locolor/16x16/apps/
install -m 644 hpoj.png $RPM_BUILD_ROOT%{_datadir}/icons/locolor/16x16/apps/

# install menu entry
#mkdir -p $RPM_BUILD_ROOT%{_menudir}

#cat <<EOF > $RPM_BUILD_ROOT%{_menudir}/xojpanel
#?package(xojpanel): needs=X11 \
#section=Applications/Monitoring \
#title="X Office Jet Panel" \
#longtitle="Displays the contents of the front panel LCD screen of your HP Office Jet in a window on your desktop" \
#command="%{_bindir}/allxojpanels" \
#icon="%{_datadir}/icons/locolor/16x16/apps/hpoj.png"
#EOF

# Install "xojpanel" wrapper
install -m 755 allxojpanels $RPM_BUILD_ROOT%{_bindir}

# Install startup script
ln -sf %{_sbindir}/ptal-init %{buildroot}%{_initrddir}/hpoj

# Directories where the daemon will create device nodes
install -d %{buildroot}/dev/ptal-mlcd
install -d %{buildroot}/dev/ptal-printd

# Backend filter for CUPS
install -d %{buildroot}%{_libdir}/cups/backend
ln -sf %{_sbindir}/ptal-cups %{buildroot}%{_libdir}/cups/backend/ptal

# Make SANE scanner driver modules available in the right place (SANE
# only finds them in /usr/lib/sane, not in /usr/lib
%if %{sane_backend}
install -d %{buildroot}%{_libdir}/sane
ln -sf %{_libdir}/libsane-hpoj.so.1.0 %{buildroot}%{_libdir}/sane
ln -sf %{_libdir}/libsane-hpoj.so.1 %{buildroot}%{_libdir}/sane
ln -sf %{_libdir}/libsane-hpoj.so %{buildroot}%{_libdir}/sane
%endif

##### PRE/POST INSTALL SCRIPTS #####

%post
# Let HPOJ daemon be automatically started at boot time
#%_post_service hpoj
/sbin/ldconfig
echo You must run "/usr/sbin/ptal-init setup" next to add the printers

%if %{sane_backend}
%post -n libsane-hpoj
/sbin/ldconfig
# Add HPOJ driver to /etc/sane.d/dll.conf
if ! grep ^hpoj /etc/sane.d/dll.conf >/dev/null 2>/dev/null ; then \
	echo hpoj >> /etc/sane.d/dll.conf; \
fi
%endif

%post -n xojpanel
# menu
%{update_menus}

%preun
# Let HPOJ daemon not be automatically started at boot time any more
#%_preun_service hpoj
%{_initrddir}/%{name} stop > /dev/null 2>&1

%if %{sane_backend}
%preun -n libsane-hpoj
# Remove HPOJ driver from /etc/sane.d/dll.conf
if [ "$1" = 0 ]; then \
	if grep ^hpoj /etc/sane.d/dll.conf >/dev/null 2>/dev/null ; then \
		sed '/hpoj/d' /etc/sane.d/dll.conf > /tmp/$$; \
		cp -f /tmp/$$ /etc/sane.d/dll.conf; \
		rm -f /tmp/$$; \
	fi; \
fi
%endif

%postun
/sbin/ldconfig

%if %{sane_backend}
%postun -n libsane-hpoj
/sbin/ldconfig
%endif

%postun -n xojpanel
## menu
%{update_menus}

##### CLEAN UP #####

%clean
rm -rf $RPM_BUILD_ROOT


##### FILE LISTS FOR ALL BINARY PACKAGES #####

##### hpoj
%files
%defattr(-,root,root)
%config(noreplace) %{_initrddir}/*
%{_sbindir}/*
%{_bindir}/ptal*
%{_bindir}/hpojip-test
%doc %{_defaultdocdir}/%{name}-%{version}
%dir /dev/ptal-mlcd
%dir /dev/ptal-printd
%{_libdir}/libptal*.so.*
%{_libdir}/libhpojip*.so.*
# CUPS backend
%{_libdir}/cups/backend/ptal

##### libsane-hpoj
%if %{sane_backend}
%files -n libsane-hpoj
%defattr(-,root,root)
%{_libdir}/libsane-hpoj*.so*
%{_libdir}/sane/libsane-hpoj*.so*
%endif

##### xojpanel
%files -n xojpanel
%defattr(-,root,root)
%{_bindir}/xojpanel
%{_bindir}/allxojpanels
# menu entry
%{_datadir}/icons/locolor/16x16/apps/*
#%{_menudir}/*

%files -n hpoj-devel
%defattr(-,root,root)
%{_includedir}/ptal*
%{_includedir}/hpojip*


##### CHANGELOG #####

%changelog
* Sat Aug 10 2002 Till Kamppeter <till@mandrakesoft.com> 0.90-3mdk
- Rebuilt with gcc-3.2-0.3mdk.

* Sat Aug 10 2002 Pixel <pixel@mandrakesoft.com> 0.90-2mdk
- fix glob with spaces to please perl-base (especially for DrakX)

* Thu Aug  8 2002 Till Kamppeter <till@mandrakesoft.com> 0.90-1mdk
- Updated to HPOJ 0.9 final.

* Wed Aug  7 2002 Till Kamppeter <till@mandrakesoft.com> 0.90-0.12mdk
- BuildRequires: libopenssl-devel

* Wed Aug  7 2002 Till Kamppeter <till@mandrakesoft.com> 0.90-0.11mdk
- The "xojpanel" package conflicts with older "hpoj" package versions, added
  appropriate "Conflicts:" entry.

* Mon Aug  5 2002 Till Kamppeter <till@mandrakesoft.com> 0.90-0.10mdk
- Updated to current CVS (lock file name fix and documentation fixes).

* Mon Jul 29 2002 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.90-0.9mdk
- Patch4: lib64 fixes in libraries lookup
- Let it build without SANE circularae dependency

* Sat Jul 27 2002 Till Kamppeter <till@mandrakesoft.com> 0.90-0.8mdk
- Updated to current CVS (Fixed xscanimage segfaulting when clicking
  on the preview area).

* Wed Jul 24 2002 Till Kamppeter <till@mandrakesoft.com> 0.90-0.7mdk
- Updated to current CVS (2nd release candidate for HPOJ 0.90).
- Corrected version number to 0.90.

* Mon Jul 22 2002 Till Kamppeter <till@mandrakesoft.com> 0.9-0.6mdk
- Updated to current CVS (1st release candidate for HPOJ 0.90).

* Thu Jun 27 2002 Till Kamppeter <till@mandrakesoft.com> 0.9-0.5mdk
- Updated to current CVS (last CVS broke printing after one or two 
  printouts).

* Mon Jun 24 2002 Till Kamppeter <till@mandrakesoft.com> 0.9-0.4mdk
- Moved menu updating in %%post and %%postun from main package to "xojpanel"
  sub package.

* Mon Jun 24 2002 Till Kamppeter <till@mandrakesoft.com> 0.9-0.3mdk
- Updated to current CVS.
- Separated off the xojpanel, so that the main package can easily be
  installed on an X-less server.

* Tue Jun 18 2002 Till Kamppeter <till@mandrakesoft.com> 0.9-0.2mdk
- Updated to current CVS
- Fixed setup for scanning (set links to scanner driver libraries, entry
  in /etc/sane.d/dll.conf)
- "ptal" backend for CUPS is in this package now
- Added "BuildRequires" line.

* Tue May 28 2002 Till Kamppeter <till@mandrakesoft.com> 0.9-0.1mdk
- Corrected path to QT 3 to make "xojpanel" getting compiled.
- Updated "allxojpanels" script.
- Bumped version number to 0.9.

* Tue May 28 2002 Till Kamppeter <till@mandrakesoft.com> 0.8-8mdk
- Updated to current CVS, version 0.8 is not compatible to gcc 3.1.
- Rebuilt for new libstdc++ and gcc 3.1.

* Sat Mar  2 2002 Till Kamppeter <till@mandrakesoft.com> 0.8-7mdk
- Fixed menu entry for "xojpanel", now a wrapper script searches for
  configured devices and starts "xojpanel" for these devices. 

* Fri Mar  1 2002 Till Kamppeter <till@mandrakesoft.com> 0.8-6mdk
- Patches for known problems from http://hpoj.sourceforge.net/todo.shtml
  (Patch2, Patch3)

* Wed Oct 24 2001 Vincent Saugey <vince@mandrakesoft.com> 0.8-5mdk
- Replace ucd-snmp require by libsnmp0

* Mon Oct 22 2001 Till Kamppeter <till@mandrakesoft.com> 0.8-4mdk
- Added patch to generate directories for the HPOJ daemons in the DevFS
  file system

* Sat Oct 20 2001 Stew Benedict <sbenedict@mandrakesoft.com> 0.8-3mdk
- patch for PPC build

* Wed Oct 10 2001 Till Kamppeter <till@mandrakesoft.com> 0.8-2mdk
- Rebuilt for libpng3.

* Wed Aug  8 2001 Till Kamppeter <till@mandrakesoft.com> 0.8-1mdk
- initial release
